==> huaweicloudsdkcse-3.1.103-py2.py3-none-any.whl: huaweicloudsdkcse/v1/model/engine_create_req_maintenance_config.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class EngineCreateReqMaintenanceConfig:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'time': 'str',
        'zone': 'str'
    }

    attribute_map = {
        'time': 'time',
        'zone': 'zone'
    }

    def __init__(self, time=None, zone=None):
        """EngineCreateReqMaintenanceConfig

        The model defined in huaweicloud sdk

        :param time: 维护时间
        :type time: str
        :param zone: 维护时间的时区
        :type zone: str
        """
        
        

        self._time = None
        self._zone = None
        self.discriminator = None

        if time is not None:
            self.time = time
        if zone is not None:
            self.zone = zone

    @property
    def time(self):
        """Gets the time of this EngineCreateReqMaintenanceConfig.

        维护时间

        :return: The time of this EngineCreateReqMaintenanceConfig.
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this EngineCreateReqMaintenanceConfig.

        维护时间

        :param time: The time of this EngineCreateReqMaintenanceConfig.
        :type time: str
        """
        self._time = time

    @property
    def zone(self):
        """Gets the zone of this EngineCreateReqMaintenanceConfig.

        维护时间的时区

        :return: The zone of this EngineCreateReqMaintenanceConfig.
        :rtype: str
        """
        return self._zone

    @zone.setter
    def zone(self, zone):
        """Sets the zone of this EngineCreateReqMaintenanceConfig.

        维护时间的时区

        :param zone: The zone of this EngineCreateReqMaintenanceConfig.
        :type zone: str
        """
        self._zone = zone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EngineCreateReqMaintenanceConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcse-3.1.153-py2.py3-none-any.whl: huaweicloudsdkcse/v1/model/engine_create_req_maintenance_config.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class EngineCreateReqMaintenanceConfig:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'time': 'str',
        'zone': 'str'
    }

    attribute_map = {
        'time': 'time',
        'zone': 'zone'
    }

    def __init__(self, time=None, zone=None):
        r"""EngineCreateReqMaintenanceConfig

        The model defined in huaweicloud sdk

        :param time: 维护时间
        :type time: str
        :param zone: 维护时间的时区
        :type zone: str
        """
        
        

        self._time = None
        self._zone = None
        self.discriminator = None

        if time is not None:
            self.time = time
        if zone is not None:
            self.zone = zone

    @property
    def time(self):
        r"""Gets the time of this EngineCreateReqMaintenanceConfig.

        维护时间

        :return: The time of this EngineCreateReqMaintenanceConfig.
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        r"""Sets the time of this EngineCreateReqMaintenanceConfig.

        维护时间

        :param time: The time of this EngineCreateReqMaintenanceConfig.
        :type time: str
        """
        self._time = time

    @property
    def zone(self):
        r"""Gets the zone of this EngineCreateReqMaintenanceConfig.

        维护时间的时区

        :return: The zone of this EngineCreateReqMaintenanceConfig.
        :rtype: str
        """
        return self._zone

    @zone.setter
    def zone(self, zone):
        r"""Sets the zone of this EngineCreateReqMaintenanceConfig.

        维护时间的时区

        :param zone: The zone of this EngineCreateReqMaintenanceConfig.
        :type zone: str
        """
        self._zone = zone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EngineCreateReqMaintenanceConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
